@@ -15,10 +15,11 @@ from intellifire4py.model import IntelliFirePollData
 from .const import IntelliFireCommand
 from .const import _log
 from .control import IntelliFireControlMode, IntelliFireController
+from .read import IntelliFireDataProvider
 from .utils import _range_check
 
 
-class IntelliFireAPILocal(IntelliFireController):
+class IntelliFireAPILocal(IntelliFireController, IntelliFireDataProvider):
     """Top level API for IntelliFire Data - local network only."""
 
     _control_mode = IntelliFireControlMode.LOCAL
@@ -46,7 +47,7 @@ class IntelliFireAPILocal(IntelliFireController):
         self._user_id = user_id
         self._last_thermostat_setpoint: int = 2100
         self.send_mode = IntelliFireControlMode.LOCAL
-        self.is_polling_in_background = False
+        self._is_polling_in_background = False
         self._should_poll_in_background = False
         self.is_sending = False
         self.failed_poll_attempts = 0
@@ -70,7 +71,7 @@ class IntelliFireAPILocal(IntelliFireController):
             "\tIntelliFireAPILocal Status\n\tis_sending\t[%s]\n\tfailed_polls\t[%d]\n\tBG_Running\t[%s]\n\tBG_ShouldRun\t[%s]",
             self.is_sending,
             self.failed_poll_attempts,
-            self.is_polling_in_background,
+            self._is_polling_in_background,
             self._should_poll_in_background,
         )
 
@@ -85,6 +86,11 @@ class IntelliFireAPILocal(IntelliFireController):
             _log.warning("Returning uninitialized poll data")
         return self._data
 
+    @property
+    def is_polling_in_background(self) -> bool:
+        """Return whether api is polling."""
+        return self._is_polling_in_background
+
     async def start_background_polling(self, minimum_wait_in_seconds: int = 15) -> None:
         """Start an ensure-future background polling loop."""
         if self.is_sending:
@@ -100,7 +106,7 @@ class IntelliFireAPILocal(IntelliFireController):
                 name="background_polling",
             )
 
-    def stop_background_polling(self, is_sending: bool) -> bool:
+    def stop_background_polling(self) -> bool:
         """Stop background polling - return whether it had been polling."""
         self._should_poll_in_background = False
         was_running = False
@@ -118,7 +124,7 @@ class IntelliFireAPILocal(IntelliFireController):
 
         self.failed_poll_attempts = 0
 
-        self.is_polling_in_background = True
+        self._is_polling_in_background = True
         while self._should_poll_in_background:
             start = time.time()
             _log.debug("__background_poll:: Loop start time %f", start)
@@ -153,7 +159,7 @@ class IntelliFireAPILocal(IntelliFireController):
                     "__background_poll:: Polling error [x%d]", self.failed_poll_attempts
                 )
 
-        self.is_polling_in_background = False
+        self._is_polling_in_background = False
         _log.info("__background_poll:: Background polling disabled.")
 
     async def poll(self, suppress_warnings: bool = False) -> None:
